GigaSpacingCollectionFind extension

Extension so that it cannot be overwritten by users

adds the find function which selects the right value

on

Methods

find(double width) → GigaSpacing

Available on GigaSpacingCollection, provided by the GigaSpacingCollectionFind extension