ResponsiveData class

Available extensions

Constructors

ResponsiveData(double width)

Properties

allEdgeInsets → EdgeInsets

Available on ResponsiveData, provided by the ResponsiveDataEdgeInsetsHelper extension

no setter
body → ScaledSize
final
gutter → ScaledSize
final
hashCode → int
The hash code for this object.
no setterinherited
horizontalEdgeInsets → EdgeInsets

Available on ResponsiveData, provided by the ResponsiveDataEdgeInsetsHelper extension

no setter
layoutColumns → LayoutColumns
final
margin → ScaledSize
final
padding → ScaledSize
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sizedBoxGutter → Widget

Available on ResponsiveData, provided by the ResponsiveDataWidgetHelper extension

no setter
verticalEdgeInsets → EdgeInsets

Available on ResponsiveData, provided by the ResponsiveDataEdgeInsetsHelper extension

no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited