ResponsiveLayoutColumnCollection class

Basic collection of columns

Available extensions

Constructors

ResponsiveLayoutColumnCollection({LayoutColumns xl = const LayoutColumns.xl(), LayoutColumns lg = const LayoutColumns.lg(), LayoutColumns md = const LayoutColumns.md(), LayoutColumns sm2 = const LayoutColumns.sm2(), LayoutColumns sm1 = const LayoutColumns.sm1(), LayoutColumns xs = const LayoutColumns.xs()})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
lg → LayoutColumns
final
md → LayoutColumns
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sm1 → LayoutColumns
final
sm2 → LayoutColumns
final
xl → LayoutColumns
final
xs → LayoutColumns
final

Methods

find(double width) → LayoutColumns

Available on ResponsiveLayoutColumnCollection, provided by the ResponsiveLayoutColumnCollectionFind extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited