ScaledPadding class

Inheritance
Available extensions

Constructors

ScaledPadding.lg()
Large 1440+ screens
const
ScaledPadding.md()
1240 - 1439
const
ScaledPadding.sm1()
600 - 904
const
ScaledPadding.sm2()
905 - 1239
const
ScaledPadding.xl()
Large 1920+ screens
const
ScaledPadding.xs()
0 - 599
const

Properties

allEdgeInsets → EdgeInsets

Available on ScaledSize, provided by the ScaledSizeEdgeInsetsHelper extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
horizontalEdgeInsets → EdgeInsets

Available on ScaledSize, provided by the ScaledSizeEdgeInsetsHelper extension

no setter
isFlexible → bool
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → double
finalinherited
verticalEdgeInsets → EdgeInsets

Available on ScaledSize, provided by the ScaledSizeEdgeInsetsHelper extension

no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited