ScaledSize class

Implementers
Available extensions

Constructors

ScaledSize({required double size, bool isFlexible = false})
const

Properties

allEdgeInsets → EdgeInsets

Available on ScaledSize, provided by the ScaledSizeEdgeInsetsHelper extension

no setter
hashCode → int
The hash code for this object.
no setteroverride
horizontalEdgeInsets → EdgeInsets

Available on ScaledSize, provided by the ScaledSizeEdgeInsetsHelper extension

no setter
isFlexible → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → double
final
verticalEdgeInsets → EdgeInsets

Available on ScaledSize, provided by the ScaledSizeEdgeInsetsHelper extension

no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override