SimpleSpacing class

Constructors

SimpleSpacing({double xs = 4.0, double s = 8.0, double m = 12.0, double l = 16.0, double xl = 32.0, double xxl = 56.0, double iconSize = 24})
const
SimpleSpacing.lg()
Large 1440+ screens
const
SimpleSpacing.md()
1240 - 1439
const
SimpleSpacing.sm1()
600 - 904
const
SimpleSpacing.sm2()
905 - 1239
const
SimpleSpacing.xl()
Large 1920+ screens
const
SimpleSpacing.xs()
0 - 599
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
iconSize → double
final
l → double
final
m → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
s → double
final
xl → double
final
xs → double
final
xxl → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited