SimpleSpacingCollectionFind extension

Extension so that it cannot be overwritten by users

adds the find function which selects the right value

on

Methods

find(double width) → SimpleSpacing

Available on SpacingCollection, provided by the SimpleSpacingCollectionFind extension