SpacingCollection class

holds the default values

OVERRIDE for custom Values

Override any if you only have one set of Spacings

class MySimpleSpacing extends SpacingCollection {

  @override
  SimpleSpacing get any => const SimpleSpacing(
    xs: 4.0,
    s: 8.0,
    m: 12.0,
    l: 16.0,
    xl: 32.0,
  xxl: 56.0,
  );
}
Available extensions

Constructors

SpacingCollection()
const

Properties

any → SimpleSpacing?
Override any if you don't want any responsive spacings
no setter
hashCode → int
The hash code for this object.
no setterinherited
lg → SimpleSpacing
Value for breakpoint which is by default
no setter
md → SimpleSpacing
Value for breakpoint which is by default
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sm1 → SimpleSpacing
Value for breakpoint which is by default
no setter
sm2 → SimpleSpacing
Value for breakpoint which is by default
no setter
xl → SimpleSpacing
Value for breakpoint which is by default
no setter
xs → SimpleSpacing
Value for breakpoint which is by default
no setter

Methods

find(double width) → SimpleSpacing

Available on SpacingCollection, provided by the SimpleSpacingCollectionFind extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited