ResponsiveSpacing class abstract

Global Responsive Settings class

Set your own defaults by calling setDefaults in your main.

void main() {
  ResponsiveSpacing.setDefaults(
    globalBreakpoints: Breakpoints(
      xl: const BreakpointEntry(1920, enabled: true),
      lg: const BreakpointEntry(1440),
      md: const BreakpointEntry(1240),
      sm2: const BreakpointEntry(905),
      sm1: const BreakpointEntry(600),
    ),
    globalGutter: MyResponsiveGutters(),
    globalPadding: MyResponsivePadding()
  );

  runApp(const MyApp());
}

Constructors

ResponsiveSpacing()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

globalBody ↔ ResponsiveCollection
Global Responsive Functions
getter/setter pair
globalBreakpoints ↔ Breakpoints
Global Breakpoints
getter/setter pair
globalColumns ↔ ResponsiveLayoutColumnCollection
getter/setter pair
globalGigaSpacing ↔ GigaSpacingCollection
getter/setter pair
globalGutter ↔ ResponsiveCollection
getter/setter pair
globalMargin ↔ ResponsiveCollection
getter/setter pair
globalPadding ↔ ResponsiveCollection
getter/setter pair
globalSpacing ↔ SpacingCollection
getter/setter pair

Static Methods

setDefaults({Breakpoints? globalBreakpoints, SpacingCollection? globalSpacing, GigaSpacingCollection? globalGigaSpacing, ResponsiveCollection? globalBody, ResponsiveCollection? globalMargin, ResponsiveCollection? globalPadding, ResponsiveCollection? globalGutter, ResponsiveLayoutColumnCollection? globalColumns}) → dynamic
Overwrite the default values if needed.